@@ -99,7 +99,8 @@ func main() {
 		rules.GrafanaApiKey(),
 		rules.GrafanaCloudApiToken(),
 		rules.GrafanaServiceAccountToken(),
-		rules.Hashicorp(),
+		rules.HarnessApiKey(),
+		rules.HashiCorpTerraform(),
 		rules.HashicorpField(),
 		rules.Heroku(),
 		rules.HubSpot(),
@@ -112,6 +113,8 @@ func main() {
 		rules.JWT(),
 		rules.JWTBase64(),
 		rules.KrakenAccessToken(),
+		rules.KubernetesSecretWithDataAfter(),
+		rules.KubernetesSecretWithDataBefore(),
 		rules.KucoinAccessToken(),
 		rules.KucoinSecretKey(),
 		rules.LaunchDarklyAccessToken(),
@@ -138,6 +141,7 @@ func main() {
 		rules.NytimesAccessToken(),
 		rules.OktaAccessToken(),
 		rules.OpenAI(),
+		rules.OpenshiftUserToken(),
 		rules.PlaidAccessID(),
 		rules.PlaidSecretKey(),
 		rules.PlaidAccessToken(),
