@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
@@ -10,8 +11,8 @@ func GitterAccessToken() *config.Rule {
 	r := config.Rule{
 		RuleID:      "gitter-access-token",
 		Description: "Uncovered a Gitter Access Token, which may lead to unauthorized access to chat and communication services.",
-		Regex: generateSemiGenericRegex([]string{"gitter"},
-			alphaNumericExtendedShort("40"), true),
+		Regex: utils.GenerateSemiGenericRegex([]string{"gitter"},
+			utils.AlphaNumericExtendedShort("40"), true),
 
 		Keywords: []string{
 			"gitter",
@@ -20,8 +21,8 @@ func GitterAccessToken() *config.Rule {
 
 	// validate
 	tps := []string{
-		generateSampleSecret("gitter",
-			secrets.NewSecret(alphaNumericExtendedShort("40"))),
+		utils.GenerateSampleSecret("gitter",
+			secrets.NewSecret(utils.AlphaNumericExtendedShort("40"))),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
