@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"regexp"
 
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
@@ -18,7 +19,7 @@ func Twilio() *config.Rule {
 
 	// validate
 	tps := []string{
-		"twilioAPIKey := \"SK" + secrets.NewSecret(hex("32")) + "\"",
+		"twilioAPIKey := \"SK" + secrets.NewSecret(utils.Hex("32")) + "\"",
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
